@@ -6,11 +6,12 @@ package dao
 import (
 	"context"
 	"fmt"
+	"log/slog"
 
 	"github.com/derailed/k9s/internal"
 	"github.com/derailed/k9s/internal/client"
 	"github.com/derailed/k9s/internal/render"
-	"github.com/rs/zerolog/log"
+	"github.com/derailed/k9s/internal/slogs"
 	rbacv1 "k8s.io/api/rbac/v1"
 	"k8s.io/apimachinery/pkg/apis/meta/v1/unstructured"
 	"k8s.io/apimachinery/pkg/labels"
@@ -28,7 +29,7 @@ type Policy struct {
 }
 
 // List returns available policies.
-func (p *Policy) List(ctx context.Context, ns string) ([]runtime.Object, error) {
+func (p *Policy) List(ctx context.Context, _ string) ([]runtime.Object, error) {
 	kind, ok := ctx.Value(internal.KeySubjectKind).(string)
 	if !ok {
 		return nil, fmt.Errorf("expecting a context subject kind")
@@ -66,11 +67,10 @@ func (p *Policy) loadClusterRoleBinding(kind, name string) (render.Policies, err
 
 	ns, n := client.Namespaced(name)
 	var nn []string
-	for _, crb := range crbs {
-		for _, s := range crb.Subjects {
-			s := s
+	for i := range crbs {
+		for _, s := range crbs[i].Subjects {
 			if isSameSubject(kind, ns, n, &s) {
-				nn = append(nn, crb.RoleRef.Name)
+				nn = append(nn, crbs[i].RoleRef.Name)
 			}
 		}
 	}
@@ -80,11 +80,11 @@ func (p *Policy) loadClusterRoleBinding(kind, name string) (render.Policies, err
 	}
 
 	rows := make(render.Policies, 0, len(nn))
-	for _, cr := range crs {
-		if !inList(nn, cr.Name) {
+	for i := range crs {
+		if !inList(nn, crs[i].Name) {
 			continue
 		}
-		rows = append(rows, parseRules(client.NotNamespaced, "CR:"+cr.Name, cr.Rules)...)
+		rows = append(rows, parseRules(client.NotNamespaced, "CR:"+crs[i].Name, crs[i].Rules)...)
 	}
 
 	return rows, nil
@@ -100,10 +100,13 @@ func (p *Policy) loadRoleBinding(kind, name string) (render.Policies, error) {
 		return nil, err
 	}
 	rows := make(render.Policies, 0, len(crs))
-	for _, cr := range crs {
-		if rbNs, ok := rbsMap["ClusterRole:"+cr.Name]; ok {
-			log.Debug().Msgf("Loading rules for clusterrole %q:%q", rbNs, cr.Name)
-			rows = append(rows, parseRules(rbNs, "CR:"+cr.Name, cr.Rules)...)
+	for i := range crs {
+		if rbNs, ok := rbsMap["ClusterRole:"+crs[i].Name]; ok {
+			slog.Debug("Loading rules for clusterrole",
+				slogs.Namespace, rbNs,
+				slogs.ResName, crs[i].Name,
+			)
+			rows = append(rows, parseRules(rbNs, "CR:"+crs[i].Name, crs[i].Rules)...)
 		}
 	}
 
@@ -111,19 +114,22 @@ func (p *Policy) loadRoleBinding(kind, name string) (render.Policies, error) {
 	if err != nil {
 		return nil, err
 	}
-	for _, ro := range ros {
-		if _, ok := rbsMap["Role:"+ro.Name]; !ok {
+	for i := range ros {
+		if _, ok := rbsMap["Role:"+ros[i].Name]; !ok {
 			continue
 		}
-		log.Debug().Msgf("Loading rules for role %q:%q", ro.Namespace, ro.Name)
-		rows = append(rows, parseRules(ro.Namespace, "RO:"+ro.Name, ro.Rules)...)
+		slog.Debug("Loading rules for role",
+			slogs.Namespace, ros[i].Namespace,
+			slogs.ResName, ros[i].Name,
+		)
+		rows = append(rows, parseRules(ros[i].Namespace, "RO:"+ros[i].Name, ros[i].Rules)...)
 	}
 
 	return rows, nil
 }
 
 func fetchClusterRoleBindings(f Factory) ([]rbacv1.ClusterRoleBinding, error) {
-	oo, err := f.List(crbGVR, client.ClusterScope, false, labels.Everything())
+	oo, err := f.List(client.CrbGVR, client.ClusterScope, false, labels.Everything())
 	if err != nil {
 		return nil, err
 	}
@@ -141,7 +147,7 @@ func fetchClusterRoleBindings(f Factory) ([]rbacv1.ClusterRoleBinding, error) {
 }
 
 func fetchRoleBindings(f Factory) ([]rbacv1.RoleBinding, error) {
-	oo, err := f.List(rbGVR, client.ClusterScope, false, labels.Everything())
+	oo, err := f.List(client.RobGVR, client.ClusterScope, false, labels.Everything())
 	if err != nil {
 		return nil, err
 	}
@@ -166,11 +172,10 @@ func (p *Policy) fetchRoleBindingNamespaces(kind, name string) (map[string]strin
 
 	ns, n := client.Namespaced(name)
 	ss := make(map[string]string, len(rbs))
-	for _, rb := range rbs {
-		for _, s := range rb.Subjects {
-			s := s
+	for i := range rbs {
+		for _, s := range rbs[i].Subjects {
 			if isSameSubject(kind, ns, n, &s) {
-				ss[rb.RoleRef.Kind+":"+rb.RoleRef.Name] = rb.Namespace
+				ss[rbs[i].RoleRef.Kind+":"+rbs[i].RoleRef.Name] = rbs[i].Namespace
 			}
 		}
 	}
@@ -193,9 +198,7 @@ func isSameSubject(kind, ns, name string, subject *rbacv1.Subject) bool {
 }
 
 func (p *Policy) fetchClusterRoles() ([]rbacv1.ClusterRole, error) {
-	const gvr = "rbac.authorization.k8s.io/v1/clusterroles"
-
-	oo, err := p.getFactory().List(gvr, client.ClusterScope, false, labels.Everything())
+	oo, err := p.getFactory().List(client.CrGVR, client.ClusterScope, false, labels.Everything())
 	if err != nil {
 		return nil, err
 	}
@@ -213,9 +216,7 @@ func (p *Policy) fetchClusterRoles() ([]rbacv1.ClusterRole, error) {
 }
 
 func (p *Policy) fetchRoles() ([]rbacv1.Role, error) {
-	const gvr = "rbac.authorization.k8s.io/v1/roles"
-
-	oo, err := p.getFactory().List(gvr, client.BlankNamespace, false, labels.Everything())
+	oo, err := p.getFactory().List(client.RoGVR, client.BlankNamespace, false, labels.Everything())
 	if err != nil {
 		return nil, err
 	}
