@@ -4,14 +4,18 @@
 package render
 
 import (
+	"context"
 	"errors"
 	"fmt"
+	"log/slog"
 	"sort"
 	"strconv"
 	"strings"
 
 	"github.com/derailed/k9s/internal/client"
+	"github.com/derailed/k9s/internal/config"
 	"github.com/derailed/k9s/internal/model1"
+	"github.com/derailed/k9s/internal/slogs"
 	"github.com/derailed/tview"
 	v1 "k8s.io/api/core/v1"
 	"k8s.io/apimachinery/pkg/apis/meta/v1/unstructured"
@@ -43,6 +47,7 @@ var defaultNOHeader = model1.Header{
 	model1.HeaderColumn{Name: "%MEM", Attrs: model1.Attrs{Align: tview.AlignRight, MX: true}},
 	model1.HeaderColumn{Name: "CPU/A", Attrs: model1.Attrs{Align: tview.AlignRight, MX: true}},
 	model1.HeaderColumn{Name: "MEM/A", Attrs: model1.Attrs{Align: tview.AlignRight, MX: true}},
+	model1.HeaderColumn{Name: "GPU"},
 	model1.HeaderColumn{Name: "LABELS", Attrs: model1.Attrs{Wide: true}},
 	model1.HeaderColumn{Name: "VALID", Attrs: model1.Attrs{Wide: true}},
 	model1.HeaderColumn{Name: "AGE", Attrs: model1.Attrs{Time: true}},
@@ -122,6 +127,7 @@ func (n Node) defaultRow(nwm *NodeWithMetrics, r *model1.Row) error {
 		client.ToPercentageStr(c.mem, a.mem),
 		toMc(a.cpu),
 		toMi(a.mem),
+		n.gpuSpec(no.Status.Capacity, no.Status.Allocatable),
 		mapToStr(no.Labels),
 		AsStatus(n.diagnose(statuses)),
 		ToAge(no.GetCreationTimestamp()),
@@ -130,6 +136,40 @@ func (n Node) defaultRow(nwm *NodeWithMetrics, r *model1.Row) error {
 	return nil
 }
 
+func (Node) gpuSpec(capacity, allocatable v1.ResourceList) string {
+	spec := NAValue
+	for k, v := range config.KnownGPUVendors {
+		key := v1.ResourceName(v)
+		if capacity, ok := capacity[key]; ok {
+			if allocs, ok := allocatable[key]; ok {
+				spec = fmt.Sprintf("%s/%s (%s)", capacity.String(), allocs.String(), k)
+				break
+			}
+		}
+	}
+
+	return spec
+}
+
+// Healthy checks component health.
+func (n Node) Healthy(_ context.Context, o any) error {
+	nwm, ok := o.(*NodeWithMetrics)
+	if !ok {
+		slog.Error("Expected *NodeWithMetrics", slogs.Type, fmt.Sprintf("%T", o))
+		return nil
+	}
+	var no v1.Node
+	err := runtime.DefaultUnstructuredConverter.FromUnstructured(nwm.Raw.Object, &no)
+	if err != nil {
+		slog.Error("Failed to convert unstructured to Node", slogs.Error, err)
+		return nil
+	}
+	ss := make([]string, 10)
+	status(no.Status.Conditions, no.Spec.Unschedulable, ss)
+
+	return n.diagnose(ss)
+}
+
 func (Node) diagnose(ss []string) error {
 	if len(ss) == 0 {
 		return nil
