@@ -4,12 +4,15 @@
 package render
 
 import (
+	"context"
 	"fmt"
+	"log/slog"
 	"strconv"
 	"strings"
 
 	"github.com/derailed/k9s/internal/client"
 	"github.com/derailed/k9s/internal/model1"
+	"github.com/derailed/k9s/internal/slogs"
 	"github.com/derailed/tcell/v2"
 	"github.com/derailed/tview"
 	v1 "k8s.io/api/core/v1"
@@ -18,6 +21,7 @@ import (
 	"k8s.io/apimachinery/pkg/apis/meta/v1/unstructured"
 	"k8s.io/apimachinery/pkg/runtime"
 	"k8s.io/apimachinery/pkg/runtime/schema"
+	"k8s.io/apimachinery/pkg/util/sets"
 	mv1beta1 "k8s.io/metrics/pkg/apis/metrics/v1beta1"
 )
 
@@ -154,8 +158,11 @@ func (p *Pod) defaultRow(pwm *PodWithMetrics, row *model1.Row) error {
 	}
 
 	dt := pwm.Raw.GetDeletionTimestamp()
-	_, _, irc, _ := p.Statuses(st.InitContainerStatuses)
-	cr, _, rc, lr := p.Statuses(st.ContainerStatuses)
+	cReady, _, cRestarts, lastRestart := p.ContainerStats(st.ContainerStatuses)
+
+	iReady, iTerminated, iRestarts := p.initContainerStats(spec.InitContainers, st.InitContainerStatuses)
+	cReady += iReady
+	allCounts := len(spec.Containers) + iTerminated
 
 	var ccmx []mv1beta1.ContainerMetrics
 	if pwm.MX != nil {
@@ -172,10 +179,10 @@ func (p *Pod) defaultRow(pwm *PodWithMetrics, row *model1.Row) error {
 		n,
 		computeVulScore(ns, pwm.Raw.GetLabels(), spec),
 		"●",
-		strconv.Itoa(cr) + "/" + strconv.Itoa(len(spec.Containers)),
+		strconv.Itoa(cReady) + "/" + strconv.Itoa(allCounts),
 		phase,
-		strconv.Itoa(rc + irc),
-		ToAge(lr),
+		strconv.Itoa(cRestarts + iRestarts),
+		ToAge(lastRestart),
 		toMc(c.cpu),
 		toMi(c.mem),
 		toMc(r.cpu) + ":" + toMc(r.lcpu),
@@ -191,13 +198,42 @@ func (p *Pod) defaultRow(pwm *PodWithMetrics, row *model1.Row) error {
 		asReadinessGate(spec, &st),
 		p.mapQOS(st.QOSClass),
 		mapToStr(pwm.Raw.GetLabels()),
-		AsStatus(p.diagnose(phase, cr, len(st.ContainerStatuses))),
+		AsStatus(p.diagnose(phase, cReady, allCounts)),
 		ToAge(pwm.Raw.GetCreationTimestamp()),
 	}
 
 	return nil
 }
 
+// Healthy checks component health.
+func (p *Pod) Healthy(_ context.Context, o any) error {
+	pwm, ok := o.(*PodWithMetrics)
+	if !ok {
+		slog.Error("Expected *PodWithMetrics", slogs.Type, fmt.Sprintf("%T", o))
+		return nil
+	}
+	var st v1.PodStatus
+	if err := runtime.DefaultUnstructuredConverter.FromUnstructured(pwm.Raw.Object["status"].(map[string]any), &st); err != nil {
+		slog.Error("Failed to convert unstructured to PodState", slogs.Error, err)
+		return nil
+	}
+	spec := new(v1.PodSpec)
+	if err := runtime.DefaultUnstructuredConverter.FromUnstructured(pwm.Raw.Object["spec"].(map[string]any), spec); err != nil {
+		slog.Error("Failed to convert unstructured to PodSpec", slogs.Error, err)
+		return nil
+	}
+	dt := pwm.Raw.GetDeletionTimestamp()
+	phase := p.Phase(dt, spec, &st)
+	cr, _, _, _ := p.ContainerStats(st.ContainerStatuses)
+	ct := len(st.ContainerStatuses)
+
+	icr, ict, _ := p.initContainerStats(spec.InitContainers, st.InitContainerStatuses)
+	cr += icr
+	ct += ict
+
+	return p.diagnose(phase, cr, ct)
+}
+
 func (*Pod) diagnose(phase string, cr, ct int) error {
 	if phase == Completed {
 		return nil
@@ -336,16 +372,16 @@ func (*Pod) mapQOS(class v1.PodQOSClass) string {
 	}
 }
 
-// Statuses reports current pod container statuses.
-func (*Pod) Statuses(cc []v1.ContainerStatus) (cr, ct, rc int, latest metav1.Time) {
+// ContainerStats reports pod container stats.
+func (*Pod) ContainerStats(cc []v1.ContainerStatus) (readyCnt, terminatedCnt, restartCnt int, latest metav1.Time) {
 	for i := range cc {
 		if cc[i].State.Terminated != nil {
-			ct++
+			terminatedCnt++
 		}
 		if cc[i].Ready {
-			cr++
+			readyCnt++
 		}
-		rc += int(cc[i].RestartCount)
+		restartCnt += int(cc[i].RestartCount)
 
 		if t := cc[i].LastTerminationState.Terminated; t != nil {
 			ts := cc[i].LastTerminationState.Terminated.FinishedAt
@@ -358,6 +394,20 @@ func (*Pod) Statuses(cc []v1.ContainerStatus) (cr, ct, rc int, latest metav1.Tim
 	return
 }
 
+func (*Pod) initContainerStats(cc []v1.Container, cos []v1.ContainerStatus) (ready, total, restart int) {
+	for i := range cos {
+		if !IsSideCarContainer(cc[i].RestartPolicy) {
+			continue
+		}
+		total++
+		if cos[i].Ready {
+			ready++
+		}
+		restart += int(cos[i].RestartCount)
+	}
+	return
+}
+
 // Phase reports the given pod phase.
 func (p *Pod) Phase(dt *metav1.Time, spec *v1.PodSpec, st *v1.PodStatus) string {
 	status := string(st.Phase)
@@ -409,13 +459,15 @@ func (*Pod) containerPhase(st *v1.PodStatus, status string) (string, bool) {
 
 func (*Pod) initContainerPhase(spec *v1.PodSpec, pst *v1.PodStatus, status string) (string, bool) {
 	count := len(spec.InitContainers)
-	rs := make(map[string]bool, count)
+	sidecars := sets.New[string]()
 	for i := range spec.InitContainers {
 		co := spec.InitContainers[i]
-		rs[co.Name] = restartableInitCO(co.RestartPolicy)
+		if IsSideCarContainer(co.RestartPolicy) {
+			sidecars.Insert(co.Name)
+		}
 	}
 	for i := range pst.InitContainerStatuses {
-		if s := checkInitContainerStatus(&pst.InitContainerStatuses[i], i, count, rs[pst.InitContainerStatuses[i].Name]); s != "" {
+		if s := checkInitContainerStatus(&pst.InitContainerStatuses[i], i, count, sidecars.Has(pst.InitContainerStatuses[i].Name)); s != "" {
 			return s, true
 		}
 	}
@@ -537,7 +589,7 @@ func hasPodReadyCondition(conditions []v1.PodCondition) bool {
 	return false
 }
 
-func restartableInitCO(p *v1.ContainerRestartPolicy) bool {
+func IsSideCarContainer(p *v1.ContainerRestartPolicy) bool {
 	return p != nil && *p == v1.ContainerRestartPolicyAlways
 }
 
