@@ -27,6 +27,15 @@ func NewInterpreter(s string) *Interpreter {
 	return &c
 }
 
+func (c *Interpreter) TrimNS() string {
+	if !c.HasNS() {
+		return c.line
+	}
+	ns, _ := c.NSArg()
+
+	return strings.TrimSpace(strings.Replace(c.line, ns, "", 1))
+}
+
 func (c *Interpreter) grok() {
 	ff := strings.Fields(c.line)
 	if len(ff) == 0 {
@@ -130,11 +139,11 @@ func (c *Interpreter) IsRBACCmd() bool {
 
 // ContextArg returns context cmd arg.
 func (c *Interpreter) ContextArg() (string, bool) {
-	if !c.IsContextCmd() {
-		return "", false
+	if c.IsContextCmd() || strings.Contains(c.line, contextFlag) {
+		return c.args[contextKey], true
 	}
 
-	return c.args[contextKey], true
+	return "", false
 }
 
 // ResetContextArg deletes context arg.
