@@ -16,6 +16,7 @@ import (
 	"github.com/derailed/k9s/internal/model"
 	"github.com/derailed/k9s/internal/slogs"
 	"github.com/derailed/k9s/internal/view/cmd"
+	"k8s.io/apimachinery/pkg/labels"
 	"k8s.io/apimachinery/pkg/util/sets"
 )
 
@@ -199,15 +200,15 @@ func (c *Command) run(p *cmd.Interpreter, fqn string, clearStack, pushCmd bool)
 
 	co := c.componentFor(gvr, fqn, v)
 	co.SetFilter("")
-	co.SetLabelFilter(nil)
+	co.SetLabelSelector(labels.Everything())
 	if f, ok := p.FilterArg(); ok {
 		co.SetFilter(f)
 	}
 	if f, ok := p.FuzzyArg(); ok {
 		co.SetFilter("-f " + f)
 	}
-	if ll, ok := p.LabelsArg(); ok {
-		co.SetLabelFilter(ll)
+	if ss, ok := p.LabelsArg(); ok {
+		co.SetLabelSelector(labels.SelectorFromSet(ss))
 	}
 
 	return c.exec(p, gvr, co, clearStack, pushCmd)
@@ -228,11 +229,11 @@ func (c *Command) defaultCmd(isRoot bool) error {
 	}
 
 	if err := c.run(p, "", true, true); err != nil {
-		p = p.Reset(defCmd)
 		slog.Error("Command exec failed. Using default command",
 			slogs.Command, p.GetLine(),
 			slogs.Error, err,
 		)
+		p = p.Reset(defCmd)
 		return c.run(p, "", true, true)
 	}
 
@@ -330,9 +331,8 @@ func (c *Command) exec(p *cmd.Interpreter, gvr *client.GVR, comp model.Component
 			slog.Error("Dumping stack", slogs.Stack, string(debug.Stack()))
 
 			ci := cmd.NewInterpreter(podCmd)
-			cmds := c.app.cmdHistory.List()
-			currentCommand := cmds[c.app.cmdHistory.CurrentIndex()]
-			if currentCommand != podCmd {
+			currentCommand, ok := c.app.cmdHistory.Top()
+			if ok {
 				ci = ci.Reset(currentCommand)
 			}
 			err = c.run(ci, "", true, true)
